<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hi_IN">
<context>
    <name>AppMain</name>
    <message>
        <location filename="../src/common/vlcplayer.cpp" line="87"/>
        <source>Voice Notes</source>
        <translation>वाणी नोट्स</translation>
    </message>
</context>
<context>
    <name>DefaultName</name>
    <message>
        <location filename="../src/db/vnotefolderoper.cpp" line="249"/>
        <source>Notebook</source>
        <translation>नोटबुक</translation>
    </message>
    <message>
        <location filename="../src/importolddata/olddbvisistors.cpp" line="139"/>
        <source>Voice</source>
        <translation>वाणी</translation>
    </message>
    <message>
        <location filename="../src/db/vnoteitemoper.cpp" line="226"/>
        <source>Text</source>
        <translation>पाठ</translation>
    </message>
</context>
<context>
    <name>FolderListView</name>
    <message>
        <location filename="../src/gui/mainwindow/FolderListView.qml" line="517"/>
        <source>Rename</source>
        <translation type="unfinished">नाम बदलें</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/FolderListView.qml" line="526"/>
        <source>Delete</source>
        <translation type="unfinished">हटाएँ</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/FolderListView.qml" line="545"/>
        <source>New Note</source>
        <translation>नई नोट</translation>
    </message>
</context>
<context>
    <name>InitialInterface</name>
    <message>
        <location filename="../src/gui/mainwindow/InitialInterface.qml" line="66"/>
        <source>After creating a new notepad, you can start recording voice and text</source>
        <translation>एक नए नोटपैड के बाद, आप वॉइस और पाठ के रिकॉर्डिंग शुरू कर सकते हैं</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/InitialInterface.qml" line="73"/>
        <source>Create Notebook</source>
        <translation type="unfinished">नोटबुक बनाएँ</translation>
    </message>
</context>
<context>
    <name>ItemListView</name>
    <message>
        <location filename="../src/gui/mainwindow/ItemListView.qml" line="79"/>
        <source>move </source>
        <translation>मूव </translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/ItemListView.qml" line="79"/>
        <source> notes to :</source>
        <translation> नोट्स को : </translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/ItemListView.qml" line="81"/>
        <source> note to :</source>
        <translation> नोट को : </translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/ItemListView.qml" line="160"/>
        <source>Save As</source>
        <translation>सेव करें के रूप में</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/ItemListView.qml" line="279"/>
        <source>No search results</source>
        <translation type="unfinished">खोजने पर कोई परिणाम नहीं मिला</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/ItemListView.qml" line="295"/>
        <source>Unpin</source>
        <translation>अनपिन करें</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/ItemListView.qml" line="295"/>
        <source>Sticky on Top</source>
        <translation type="unfinished">शीर्ष पर तारांकित</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/ItemListView.qml" line="752"/>
        <source>Sticky Notes</source>
        <translation type="unfinished">तारांकित नोट्स</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/gui/mainwindow/MainWindow.qml" line="370"/>
        <source>Create Notebook</source>
        <translation type="unfinished">नोटबुक बनाएँ</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/MainWindow.qml" line="523"/>
        <source>Search</source>
        <translation type="unfinished">खोजें</translation>
    </message>
</context>
<context>
    <name>MoveDialog</name>
    <message>
        <location filename="../src/gui/dialog/MoveDialog.qml" line="24"/>
        <source>Move Note</source>
        <translation>नोट मूव करें</translation>
    </message>
    <message>
        <location filename="../src/gui/dialog/MoveDialog.qml" line="136"/>
        <source>Cancel</source>
        <translation type="unfinished">रद्द करें</translation>
    </message>
    <message>
        <location filename="../src/gui/dialog/MoveDialog.qml" line="153"/>
        <source>Ok</source>
        <translation>ओके</translation>
    </message>
</context>
<context>
    <name>MultipleChoices</name>
    <message>
        <location filename="../src/gui/mainwindow/MultipleChoices.qml" line="37"/>
        <source>%1 note selected</source>
        <translation>%1 नोट चयनित किया गया</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/MultipleChoices.qml" line="56"/>
        <source>Move</source>
        <translation type="unfinished">अंतरित करें</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/MultipleChoices.qml" line="69"/>
        <source>Save Note</source>
        <translation>सेव नोट</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/MultipleChoices.qml" line="82"/>
        <source>Save Voice</source>
        <translation>सेव वॉइस</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/MultipleChoices.qml" line="93"/>
        <source>Delete</source>
        <translation type="unfinished">हटाएँ</translation>
    </message>
</context>
<context>
    <name>NoteDetailContextMenu</name>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="69"/>
        <source>Save as MP3</source>
        <translation>Mp3 के रूप में संचित करें</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="70"/>
        <source>Voice to Text</source>
        <translation>वाणी से टेक्स्ट</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="71"/>
        <source>Delete</source>
        <translation>हटाएँ</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="72"/>
        <source>Select all</source>
        <translation>सभी का चयन करें</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="73"/>
        <source>Copy</source>
        <translation>कॉपी करेें</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="74"/>
        <source>Cut</source>
        <translation>कट करें</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="75"/>
        <source>Paste</source>
        <translation>पेस्ट करें</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="78"/>
        <source>View</source>
        <translation>देखें</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="84"/>
        <source>Save as</source>
        <translation>सेव करें के रूप में</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="93"/>
        <source>Text to Speech</source>
        <translation>पाठ से वॉइस</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="94"/>
        <source>Stop reading</source>
        <translation>पढ़ना बंद करें</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="95"/>
        <source>Speech to Text</source>
        <translation>वॉइस से पाठ</translation>
    </message>
</context>
<context>
    <name>NotebookContextMenu</name>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="47"/>
        <source>Rename</source>
        <translation>नाम बदलें</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="48"/>
        <source>Delete</source>
        <translation>हटाएँ</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="49"/>
        <source>New note</source>
        <translation type="unfinished">नया नोट</translation>
    </message>
</context>
<context>
    <name>NotesContextMenu</name>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="63"/>
        <source>Save as HTML</source>
        <translation>एचटीएमएल के रूप में संचित करें</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="64"/>
        <source>Save as TXT</source>
        <translation>txt के रूप में संचित करें</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="57"/>
        <source>Save note</source>
        <translation>नोट संचित करें</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="52"/>
        <source>Rename</source>
        <translation>नाम बदलें</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="54"/>
        <source>Move</source>
        <translation>अंतरित करें</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="55"/>
        <source>Delete</source>
        <translation>हटाएँ</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="58"/>
        <source>Save voice recording</source>
        <translation>वाणी रिकॉर्डिंग संचित करें</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="60"/>
        <source>New note</source>
        <translation>नया नोट</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="53"/>
        <source>Sticky on Top</source>
        <translation>शीर्ष पर तारांकित</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/common/vtextspeechandtrmanager.cpp" line="261"/>
        <source>Please install 'UOS AI' from the App Store before using</source>
        <translation>उपयोग करने से पहले 'UOS AI' को ऐप स्टोर से स्थापित करें</translation>
    </message>
    <message>
        <location filename="../src/common/vtextspeechandtrmanager.cpp" line="263"/>
        <source>No audio input device detected. Please check and try again</source>
        <translation>कोई ऑडियो इनपुट डिवाइस नहीं डिटेक्ट किया गया। कृपया जांच करें और पुन: प्रयास करें</translation>
    </message>
    <message>
        <location filename="../src/common/vtextspeechandtrmanager.cpp" line="265"/>
        <source>No audio output device detected. Please check and try again</source>
        <translation>कोई ऑडियो आउटपुट डिवाइस नहीं डिटेक्ट किया गया। कृपया जांच करें और पुन: प्रयास करें</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="99"/>
        <source>deepin-voice-note</source>
        <translation>deepin-voice-note</translation>
    </message>
</context>
<context>
    <name>Setting</name>
    <message>
        <location filename="../src/common/setting.cpp" line="24"/>
        <source>Basic</source>
        <translation>सामान्य</translation>
    </message>
    <message>
        <location filename="../src/common/setting.cpp" line="25"/>
        <source>Audio Source</source>
        <translation>ऑडियो स्रोत</translation>
    </message>
    <message>
        <location filename="../src/common/setting.cpp" line="26"/>
        <source>Internal</source>
        <translation>आंतरिक</translation>
    </message>
    <message>
        <location filename="../src/common/setting.cpp" line="27"/>
        <source>Microphone</source>
        <translation>माइक्रोफोन</translation>
    </message>
</context>
<context>
    <name>SettingDialog</name>
    <message>
        <location filename="../src/gui/dialog/SettingDialog.qml" line="27"/>
        <source>Basic</source>
        <translation type="unfinished">सामान्य</translation>
    </message>
    <message>
        <location filename="../src/gui/dialog/SettingDialog.qml" line="32"/>
        <source>Audio Source</source>
        <translation type="unfinished">ऑडियो स्रोत</translation>
    </message>
    <message>
        <location filename="../src/gui/dialog/SettingDialog.qml" line="59"/>
        <source>Internal</source>
        <translation type="unfinished">आंतरिक</translation>
    </message>
    <message>
        <location filename="../src/gui/dialog/SettingDialog.qml" line="68"/>
        <source>Microphone</source>
        <translation type="unfinished">माइक्रोफोन</translation>
    </message>
</context>
<context>
    <name>Shortcuts</name>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="804"/>
        <source>New notebook</source>
        <translation>नया नोटबुक</translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="805"/>
        <source>Rename notebook</source>
        <translation>नाम बदलें नोटबुक</translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="806"/>
        <source>Delete notebook</source>
        <translation>नोटबुक मिटाएं</translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="828"/>
        <source>New note</source>
        <translation type="unfinished">नया नोट</translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="829"/>
        <source>Rename note</source>
        <translation>नोट का नाम बदलें</translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="830"/>
        <source>Delete note</source>
        <translation>नोट मिटाएं</translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="831"/>
        <source>Play/Pause</source>
        <translation>प्ले/पैज</translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="832"/>
        <source>Record voice</source>
        <translation>वॉइस रिकॉर्ड करें</translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="833"/>
        <source>Save note</source>
        <translation type="unfinished">नोट संचित करें</translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="834"/>
        <source>Save recordings</source>
        <translation>रिकॉर्डिंग सेव करें</translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="854"/>
        <source>Select all</source>
        <translation>सभी चयन करें</translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="855"/>
        <source>Copy</source>
        <translation type="unfinished">कॉपी करेें</translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="856"/>
        <source>Cut</source>
        <translation type="unfinished">कट करें</translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="857"/>
        <source>Paste</source>
        <translation type="unfinished">पेस्ट करें</translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="858"/>
        <source>Undo</source>
        <translation>उत्तर लेना</translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="859"/>
        <source>Redo</source>
        <translation>फिर करें</translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="860"/>
        <source>Delete</source>
        <translation type="unfinished">हटाएँ</translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="883"/>
        <source>Help</source>
        <translation>सहायता</translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="884"/>
        <source>Display shortcuts</source>
        <translation>शॉर्टकट दिखाएं</translation>
    </message>
</context>
<context>
    <name>ShortcutsGroups</name>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="810"/>
        <source>Notebooks</source>
        <translation>नोटबुक</translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="838"/>
        <source>Notes</source>
        <translation>नोट</translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="864"/>
        <source>Edit</source>
        <translation>संपादित करें</translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="888"/>
        <source>Settings</source>
        <translation type="unfinished">सेटिंग्स</translation>
    </message>
</context>
<context>
    <name>TitleBarMenu</name>
    <message>
        <location filename="../src/gui/mainwindow/TitleBarMenu.qml" line="16"/>
        <source>Settings</source>
        <translation type="unfinished">सेटिंग्स</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/TitleBarMenu.qml" line="30"/>
        <source>Privacy Policy</source>
        <translation>गोपनीयता नीति</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/TitleBarMenu.qml" line="53"/>
        <source>Voice Notes is a lightweight memo tool to make text notes and voice recordings.</source>
        <translation>वॉइस नोट्स एक हल्का मेमो टूल है जिसका उपयोग टेक्स्ट नोट्स और वॉइस रिकॉर्डिंग के लिए किया जाता है।</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/TitleBarMenu.qml" line="55"/>
        <source>Voice Note</source>
        <translation>वॉइस नोट</translation>
    </message>
</context>
<context>
    <name>UpgradeView</name>
    <message>
        <location filename="../src/importolddata/upgradeview.cpp" line="35"/>
        <source>Importing notes from the old version, please wait...</source>
        <translation>पुराने संस्करण से नोट्स आयात किये जा रहे हैं, प्रतीक्षा करें ...</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <location filename="../src/common/utils.cpp" line="46"/>
        <source>1 min ago</source>
        <translation>1 मिनट पूर्व</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="48"/>
        <source>%1 mins ago</source>
        <translation>%1 मिनट पूर्व</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="56"/>
        <source>Yesterday</source>
        <translation>पिछला कल</translation>
    </message>
    <message>
        <location filename="../tests/src/common/ut_utils.cpp" line="33"/>
        <source>2 mins ago</source>
        <translation>2 मिनट पहले</translation>
    </message>
</context>
<context>
    <name>VNoteMessageDialog</name>
    <message>
        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="28"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>ठीक है</translation>
    </message>
    <message>
        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="39"/>
        <source>Are you sure you want to delete this notebook?
All notes in it will be deleted</source>
        <translation>क्या आप इस नोटबुक को हटाना चाहते हैं?
इसमें सभी नोट हटा दिए जाएंगे</translation>
    </message>
    <message>
        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="46"/>
        <source>Do you want to stop the current recording?</source>
        <translation type="unfinished">क्या आप वर्तमान रिकॉर्डिंग रोकना चाहते हैं?</translation>
    </message>
    <message>
        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="52"/>
        <source>Cannot convert this voice note, as notes over 20 minutes are not supported at present.</source>
        <translation type="unfinished">अनुप्रयोग में 20 मिनट से अधिक के नोट समर्थित नहीं है, अतः यह वाणी नोट रूपांतरित नहीं हो सका।</translation>
    </message>
    <message>
        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="59"/>
        <source>Converting a voice note now. Do you want to stop it?</source>
        <translation type="unfinished">वाणी नोट रूपांतरित किया जा रहा है। क्या आप इसे रोकना चाहते हैं?</translation>
    </message>
    <message>
        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="65"/>
        <source>The low input volume may result in bad recordings. Do you want to continue?</source>
        <translation type="unfinished">इनपुट ध्वनि कम रखने से रिकॉर्डिंग ख़राब होने की संभावना है। क्या आप जारी रखना चाहते हैं? </translation>
    </message>
    <message>
        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="72"/>
        <source>The clipped recordings and converted text will not be pasted. Do you want to continue?</source>
        <translation type="unfinished">कटी रिकॉर्डिंग व रूपांतरित टेक्स्ट पेस्ट नहीं होगा। क्या आप जारी रखना चाहते हैं?</translation>
    </message>
    <message>
        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="81"/>
        <source>Are you sure you want to delete this note?</source>
        <translation type="unfinished">क्या आप यह नोट हटाना चाहते हैं?</translation>
    </message>
    <message>
        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="87"/>
        <source>Are you sure you want to delete the selected %1 notes?</source>
        <translation type="unfinished">क्या आप निश्चित ही चयनित %1 नोट हटाना चाहते हैं?</translation>
    </message>
    <message>
        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="94"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation type="unfinished">रद्द करें</translation>
    </message>
    <message>
        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="98"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation type="unfinished">पुष्टि करें</translation>
    </message>
    <message>
        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="106"/>
        <source>Save failed</source>
        <translation type="unfinished">संचित करना विफल</translation>
    </message>
    <message>
        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="111"/>
        <source>You do not have permission to save files there</source>
        <translation type="unfinished">आपके पास उस स्थान पर फाइल संचय हेतु अनुमति नहीं है</translation>
    </message>
    <message>
        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="116"/>
        <source>The voice note has been deleted</source>
        <translation type="unfinished">वाणी नोट हटा दिया गया</translation>
    </message>
</context>
<context>
    <name>VNoteMessageDialogHandler</name>
    <message>
        <location filename="../src/handler/vnote_message_dialog_handler.cpp" line="97"/>
        <source>Are you sure you want to delete this notebook?</source>
        <translation>क्या आप इस नोटबुक को हटाना चाहते हैं?</translation>
    </message>
    <message>
        <location filename="../src/handler/vnote_message_dialog_handler.cpp" line="99"/>
        <source>Do you want to stop the current recording?</source>
        <translation type="unfinished">क्या आप वर्तमान रिकॉर्डिंग रोकना चाहते हैं?</translation>
    </message>
    <message>
        <location filename="../src/handler/vnote_message_dialog_handler.cpp" line="103"/>
        <source>Are you sure you want to delete the selected %1 notes?</source>
        <translation type="unfinished">क्या आप निश्चित ही चयनित %1 नोट हटाना चाहते हैं?</translation>
    </message>
    <message>
        <location filename="../src/handler/vnote_message_dialog_handler.cpp" line="107"/>
        <source>Are you sure you want to delete this note?</source>
        <translation type="unfinished">क्या आप यह नोट हटाना चाहते हैं?</translation>
    </message>
    <message>
        <location filename="../src/handler/vnote_message_dialog_handler.cpp" line="110"/>
        <source>Cannot convert this voice note, as notes over 20 minutes are not supported at present.</source>
        <translation type="unfinished">अनुप्रयोग में 20 मिनट से अधिक के नोट समर्थित नहीं है, अतः यह वाणी नोट रूपांतरित नहीं हो सका।</translation>
    </message>
    <message>
        <location filename="../src/handler/vnote_message_dialog_handler.cpp" line="114"/>
        <source>Converting a voice note now. Do you want to stop it?</source>
        <translation type="unfinished">वाणी नोट रूपांतरित किया जा रहा है। क्या आप इसे रोकना चाहते हैं?</translation>
    </message>
    <message>
        <location filename="../src/handler/vnote_message_dialog_handler.cpp" line="116"/>
        <source>The low input volume may result in bad recordings. Do you want to continue?</source>
        <translation type="unfinished">इनपुट ध्वनि कम रखने से रिकॉर्डिंग ख़राब होने की संभावना है। क्या आप जारी रखना चाहते हैं? </translation>
    </message>
    <message>
        <location filename="../src/handler/vnote_message_dialog_handler.cpp" line="119"/>
        <source>The clipped recordings and converted text will not be pasted. Do you want to continue?</source>
        <translation type="unfinished">कटी रिकॉर्डिंग व रूपांतरित टेक्स्ट पेस्ट नहीं होगा। क्या आप जारी रखना चाहते हैं?</translation>
    </message>
    <message>
        <location filename="../src/handler/vnote_message_dialog_handler.cpp" line="123"/>
        <source>Save failed</source>
        <translation type="unfinished">संचित करना विफल</translation>
    </message>
    <message>
        <location filename="../src/handler/vnote_message_dialog_handler.cpp" line="125"/>
        <source>You do not have permission to save files there</source>
        <translation type="unfinished">आपके पास उस स्थान पर फाइल संचय हेतु अनुमति नहीं है</translation>
    </message>
    <message>
        <location filename="../src/handler/vnote_message_dialog_handler.cpp" line="127"/>
        <source>The voice note has been deleted</source>
        <translation type="unfinished">वाणी नोट हटा दिया गया</translation>
    </message>
    <message>
        <location filename="../src/handler/vnote_message_dialog_handler.cpp" line="129"/>
        <source>The voice conversion failed due to the poor network connection, please have a check</source>
        <translation>कमजोर नेटवर्क कनेक्शन के कारण वॉइस कनवर्जन असफल रहा, कृपया जांच करें</translation>
    </message>
    <message>
        <location filename="../src/handler/vnote_message_dialog_handler.cpp" line="141"/>
        <source>All notes in it will be deleted</source>
        <translation>इसमें सभी नोट हटा दिए जाएंगे</translation>
    </message>
    <message>
        <location filename="../src/handler/vnote_message_dialog_handler.cpp" line="154"/>
        <source>Delete</source>
        <translation type="unfinished">हटाएँ</translation>
    </message>
</context>
<context>
    <name>VNoteMessageDialogLoader</name>
    <message>
        <location filename="../src/gui/dialog/VNoteMessageDialogLoader.qml" line="150"/>
        <source>Cancel</source>
        <translation type="unfinished">रद्द करें</translation>
    </message>
    <message>
        <location filename="../src/gui/dialog/VNoteMessageDialogLoader.qml" line="183"/>
        <source>Confirm</source>
        <translation type="unfinished">पुष्टि करें</translation>
    </message>
</context>
<context>
    <name>WebEngineHandler</name>
    <message>
        <location filename="../src/handler/web_engine_handler.cpp" line="647"/>
        <source>save as MP3</source>
        <translation>एमपी3 के रूप में सहेजें</translation>
    </message>
</context>
<context>
    <name>WindowTitleBar</name>
    <message>
        <location filename="../src/gui/mainwindow/WindowTitleBar.qml" line="60"/>
        <source>Create Note</source>
        <translation>नोट बनाएं</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/WindowTitleBar.qml" line="100"/>
        <source>Start recording</source>
        <translation>रिकॉर्डिंग शुरू करें</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/WindowTitleBar.qml" line="100"/>
        <source>No recording device detected</source>
        <translation>कोई रिकॉर्डिंग डिवाइस नहीं डिटेक्ट किया गया</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/WindowTitleBar.qml" line="119"/>
        <source>Insert picture</source>
        <translation>चित्र डालें</translation>
    </message>
</context>
<context>
    <name>web</name>
    <message>
        <location filename="../src/common/jscontent.cpp" line="146"/>
        <source>Font</source>
        <translation>फॉन्ट</translation>
    </message>
    <message>
        <location filename="../src/common/jscontent.cpp" line="147"/>
        <source>Font size</source>
        <translation>मुद्रलिपि आकार</translation>
    </message>
    <message>
        <location filename="../src/common/jscontent.cpp" line="148"/>
        <source>Font color</source>
        <translation>मुद्रलिपि रंग</translation>
    </message>
    <message>
        <location filename="../src/common/jscontent.cpp" line="149"/>
        <source>Text highlight color</source>
        <translation>चिन्हित टेक्स्ट का रंग</translation>
    </message>
    <message>
        <location filename="../src/common/jscontent.cpp" line="150"/>
        <source>Bold</source>
        <translation>मोटे शब्द</translation>
    </message>
    <message>
        <location filename="../src/common/jscontent.cpp" line="151"/>
        <source>Italic</source>
        <translation>तिरछे शब्द</translation>
    </message>
    <message>
        <location filename="../src/common/jscontent.cpp" line="152"/>
        <source>Underline</source>
        <translation>रेखांकित शब्द</translation>
    </message>
    <message>
        <location filename="../src/common/jscontent.cpp" line="153"/>
        <source>Strikethrough</source>
        <translation>मध्य से रेखांखित शब्द</translation>
    </message>
    <message>
        <location filename="../src/common/jscontent.cpp" line="154"/>
        <source>Bullets</source>
        <translation>बिंदु अनुक्रमित सूची</translation>
    </message>
    <message>
        <location filename="../src/common/jscontent.cpp" line="155"/>
        <source>Numbering</source>
        <translation>अंक अनुक्रमित सूची</translation>
    </message>
    <message>
        <location filename="../src/common/jscontent.cpp" line="156"/>
        <source>More colors</source>
        <translation>अधिक रंग</translation>
    </message>
    <message>
        <location filename="../src/common/jscontent.cpp" line="157"/>
        <source>Recent</source>
        <translation>हालिया</translation>
    </message>
    <message>
        <location filename="../src/common/jscontent.cpp" line="173"/>
        <source>Voice To Text</source>
        <translation>वॉइस टू टेक्स्ट</translation>
    </message>
    <message>
        <location filename="../src/common/jscontent.cpp" line="174"/>
        <source>Converting voice to text</source>
        <translation>वॉइस को टेक्स्ट में कनवर्ट कर रहे हैं</translation>
    </message>
</context>
</TS>
